# soundsig
sound signal processing
# Content
The package has routines to perform signal analysis on time series and sond waveforms in particular.  It includes:
 Spectrogram
 Modulation Power Spectrum
 Coherence
 Filtering
 Power spectrum
 Fundamental Estimation

The biosound class is used to represent a biological sound (natural sound) with multiple feature spaces.

# INSTALLATION
Coming soon!

# DOCUMENTATION and TUTORIALS
Coming soon!
